# pyrestsdk

PyREST SDK is a fully python toolkit for wrapping REST APIs or creating SDKs for REST APIs.

It includes:
- Credentials
- Client handling
- Building API paths
- Formulating complex requests
- dynamic structure to object-ify any API return

## Installing
Install and update using [pip](https://pip.pypa.io/en/stable/getting-started/):
``` bash
$ pip install -U pyrestsdk
```

## Projects using PyREST SDK:
- [pyService-Now](https://github.com/michaeldcanady/pyservicenow)